Appenders do the actual work of writing log messages to some target. To use
an appender in a logger, you must register it to a given logger. Use the
'flog.appender' function to both access and set appenders. flog.appender(name) %::% character : Function
flog.appender(name='ROOT')
flog.appender(name) %::% Function : character : Null
flog.appender(fn, name='ROOT')
'appender.console' is a function that writes to the console. No additional
arguments are necessary when registering the appender via flog.appender.
flog.appender(appender.console(), name='my.logger')
'appender.file' writes to a file, so you must pass an additional file
argument to the function.
flog.appender(appender.file('output.log'), name='my.logger')
To use your own appender create a function that takes a single argument,
which represents the log message. You need to pass a function reference
to flog.appender.